==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneAdditionalCertificateFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControlPlaneAdditionalCertificateFluent<A extends ControlPlaneAdditionalCertificateFluent<A>> extends BaseFluent<A>{
  public ControlPlaneAdditionalCertificateFluent() {
  }
  
  public ControlPlaneAdditionalCertificateFluent(ControlPlaneAdditionalCertificate instance) {
    this.copyInstance(instance);
  }
  private String domain;
  private String name;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControlPlaneAdditionalCertificate instance) {
    instance = (instance != null ? instance : new ControlPlaneAdditionalCertificate());
  
    if (instance != null) {
        this.withDomain(instance.getDomain());
        this.withName(instance.getName());
        this.withDomain(instance.getDomain());
        this.withName(instance.getName());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDomain() {
    return this.domain;
  }
  
  public A withDomain(String domain) {
    this.domain=domain; return (A) this;
  }
  
  public boolean hasDomain() {
    return this.domain != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControlPlaneAdditionalCertificateFluent that = (ControlPlaneAdditionalCertificateFluent) o;
    if (!java.util.Objects.equals(domain, that.domain)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(domain,  name,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ControlPlaneAdditionalCertificateFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControlPlaneAdditionalCertificateFluent<A extends ControlPlaneAdditionalCertificateFluent<A>> extends BaseFluent<A>{
  public ControlPlaneAdditionalCertificateFluent() {
  }
  
  public ControlPlaneAdditionalCertificateFluent(ControlPlaneAdditionalCertificate instance) {
    this.copyInstance(instance);
  }
  private String domain;
  private String name;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControlPlaneAdditionalCertificate instance) {
    instance = (instance != null ? instance : new ControlPlaneAdditionalCertificate());
    if (instance != null) {
          this.withDomain(instance.getDomain());
          this.withName(instance.getName());
          this.withDomain(instance.getDomain());
          this.withName(instance.getName());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDomain() {
    return this.domain;
  }
  
  public A withDomain(String domain) {
    this.domain = domain;
    return (A) this;
  }
  
  public boolean hasDomain() {
    return this.domain != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControlPlaneAdditionalCertificateFluent that = (ControlPlaneAdditionalCertificateFluent) o;
    if (!java.util.Objects.equals(domain, that.domain)) return false;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(domain,  name,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (domain != null) { sb.append("domain:"); sb.append(domain + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
